"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require('fs');
var glob = require('glob');
var mz = require("mz/fs");
/**
 * Reads a JSON file.
 *
 * @param file Source file name.
 */
exports.readJson = function (file) {
    return new Promise(function (resolve, reject) {
        fs.readFile(file, function (err, data) {
            if (err) {
                reject(err);
            }
            try {
                resolve(JSON.parse(data));
            }
            catch (e) {
                reject(e);
            }
        });
    });
};
/**
 * Writes a JSON file.
 *
 * @param object Object literal that is stringified.
 * @param file Target file name.
 */
exports.writeJson = function (object, file) {
    return new Promise(function (resolve, reject) {
        var content = JSON.stringify(object, undefined, 2);
        fs.writeFile(file, content, function (err) {
            if (err) {
                reject(err);
            }
            resolve();
        });
    });
};
/**
 * Modifies a set of JSON files by invoking `modifyFn`
 *
 * @param globPattern A glob pattern matching several files. Example: '**\/*.js.map'
 * @param modifyFn A callback function that tajes a JSON-parsed input and should return an output
 *                  that will be JSON-stringified
 */
exports.modifyJsonFiles = function (globPattern, modifyFn) {
    return new Promise(function (resolve, reject) {
        glob(globPattern, function (err, files) {
            if (err) {
                reject(err);
            }
            resolve(files);
        });
    })
        .then(function (fileNames) { return Promise.all(fileNames.map(function (fileName) { return mz.readFile(fileName)
        .then(function (fileContent) { return mz.writeFile(fileName, JSON.stringify(modifyFn(JSON.parse(fileContent)))); }); })); })
        .then(function () { return Promise.resolve(); });
};
//# sourceMappingURL=json.js.map