"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var json_schema_1 = require("@ngtools/json-schema");
var ng_package_1 = require("../model/ng-package");
var json_1 = require("./json");
var fs = require('fs');
var path = require('path');
var findFromDirectory = function (dir, file, cb) {
    var fileName = path.resolve(dir, file);
    fs.access(fileName, fs.constants.R_OK, function (err) {
        if (err) {
            findFromDirectory(path.resolve(dir, '..'), file, cb);
        }
        else {
            cb(fileName);
        }
    });
};
/**
 * Reads an Angular package definition file from 'ng-package.json'
 *
 * @param file `ng-package.json` definition file
 */
exports.readPackage = function (file) {
    var base = path.dirname(file);
    return json_1.readJson(file)
        .then(function (ngPkg) {
        // resolve pathes relative to `ng-package.json` file
        var dir = path.resolve(base, ngPkg.src || '.');
        return json_1.readJson(dir + "/package.json")
            .then(function (pkg) {
            return new Promise(function (resolve, reject) {
                findFromDirectory(__dirname, 'ng-package.schema.json', function (fileName) {
                    resolve(fileName);
                });
            })
                .then(function (schemaFileName) { return json_1.readJson(schemaFileName); })
                .then(function (schemaJson) {
                var NgPackageSchema = json_schema_1.SchemaClassFactory(schemaJson);
                var schema = new NgPackageSchema(ngPkg);
                return Promise.resolve(new ng_package_1.NgPackage(base, schema.$$root(), pkg));
            });
        });
    });
};
/**
 * Creates a `package.json` file by reading one from the `src` folder, adding additional
 * properties, and writing to to `dest` folder
 *
 * @param src Source folder
 * @param dest Destination folder
 * @param additionalProperties These properties are added to the `package.json`
 */
exports.createPackage = function (src, dest, additionalProperties) {
    return json_1.readJson(src + "/package.json")
        .then(function (packageJson) {
        // set additional properties
        if (additionalProperties) {
            Object.keys(additionalProperties).forEach(function (key) {
                packageJson[key] = additionalProperties[key];
            });
        }
        return json_1.writeJson(packageJson, dest + "/package.json");
    });
};
//# sourceMappingURL=package.js.map